Description Usage Arguments Details Value Examples
The following steps are done in this function
1 2 3 4 | init_LEEF(
config_file = system.file("default_config.yml", package = "LEEF"),
id = NULL
)
|
config_file |
config file to use. If none is specified, |
id |
id which will be appended to the name in the config file, using a '.' |
the config file as specified in the argument config_file is read
the folders as specified in the config file are, if they do not exist yet, created. If they are not specified, the following default values are used:
general.parameter: 00.general.parameter - the directory containing general configuratuion files which are used for multiple measurements
raw: 0.raw.data - the raw data
pre_processed: 1.pre_processed.data - the pre-processed Archive Ready Data
extracted: 2.extracted.data = the extracted Research Ready Data
archive: 3.archived.data - the archived data from any of the previous steps or raw data
backend: 9.backend - the backend which contains the Research Ready Data from all pipeline runs before
tools: tools - tools needed for running the different processes in the pipeline
verifies if a file named sample_metadata.yml exists which contains the metadata of the raw data
registers all measurement, archive and backend packages
verifies,if all tools are installed and installs them when needed. THis step is specific to the bemovi measurement!!!
invisible TRUE
1 2 3 4 | ## Not run:
init_LEEF(system.file("default_config.yml", package = "LEEF"))
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.