Description Usage Arguments Details Value Examples
View source: R/list_LEEF_packages.R
This function is a wrapper around tools::package_dependencies("LEEF",
which = "all", recursive = TRUE) which returns only the packages which
contain .LEEF or LEEF. and the package LEEF itself.
1 | list_LEEF_packages(recursive = TRUE, versions = FALSE)
|
recursive |
logical: should (reverse) dependencies of (reverse)
dependencies (and so on) be included? defaults to |
versions |
logical: should versions be returned as well. |
This function is a convenience function and only returns useful results when
all packages which are dependencies of the LEEF package are prefixed
with LEEF. or postficxed with .LEEF.
list of all packages which are installed which contain .LEEF or LEEF. and the package LEEF itself
1 2 3 4 | ## Not run:
list_LEEF_packages()
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.